==> qtwebengine-opensource-src-5.6.2.tar.xz: qtwebengine-opensource-src-5.6.2/src/3rdparty/chromium/ui/views/examples/label_example.h <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef UI_VIEWS_EXAMPLES_LABEL_EXAMPLE_H_
#define UI_VIEWS_EXAMPLES_LABEL_EXAMPLE_H_

#include "base/macros.h"
#include "ui/views/controls/button/button.h"
#include "ui/views/controls/combobox/combobox_listener.h"
#include "ui/views/controls/textfield/textfield_controller.h"
#include "ui/views/examples/example_base.h"

namespace views {

class Checkbox;
class GridLayout;
class Label;

namespace examples {

class ExampleComboboxModel;

class VIEWS_EXAMPLES_EXPORT LabelExample : public ExampleBase,
                                           public ButtonListener,
                                           public ComboboxListener,
                                           public TextfieldController {
 public:
  LabelExample();
  ~LabelExample() override;

  // ExampleBase:
  void CreateExampleView(View* container) override;

  // ButtonListener:
  void ButtonPressed(Button* button, const ui::Event& event) override;

  // ComboboxListener:
  void OnPerformAction(Combobox* combobox) override;

  // TextfieldController:
  void ContentsChanged(Textfield* sender,
                       const base::string16& new_contents) override;

 private:
   // Add a customizable label and various controls to modify its presentation.
   void AddCustomLabel(View* container);

   // Creates and adds a combobox to the layout.
   Combobox* AddCombobox(GridLayout* layout,
                         const char* name,
                         const char** strings,
                         int count);

  Textfield* textfield_;
  Combobox* alignment_;
  Combobox* elide_behavior_;
  ScopedVector<ExampleComboboxModel> example_combobox_models_;
  Checkbox* multiline_;
  Checkbox* shadows_;
  Label* custom_label_;

  DISALLOW_COPY_AND_ASSIGN(LabelExample);
};

}  // namespace examples
}  // namespace views

#endif  // UI_VIEWS_EXAMPLES_LABEL_EXAMPLE_H_

==> qtwebengine-opensource-src_5.7.1+dfsg.orig.tar.xz: qtwebengine-opensource-src-5.7.1/src/3rdparty/chromium/ui/views/examples/label_example.h <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef UI_VIEWS_EXAMPLES_LABEL_EXAMPLE_H_
#define UI_VIEWS_EXAMPLES_LABEL_EXAMPLE_H_

#include "base/macros.h"
#include "ui/views/controls/button/button.h"
#include "ui/views/controls/combobox/combobox_listener.h"
#include "ui/views/controls/textfield/textfield_controller.h"
#include "ui/views/examples/example_base.h"

namespace views {

class Checkbox;
class GridLayout;
class Label;

namespace examples {

class ExampleComboboxModel;

class VIEWS_EXAMPLES_EXPORT LabelExample : public ExampleBase,
                                           public ButtonListener,
                                           public ComboboxListener,
                                           public TextfieldController {
 public:
  LabelExample();
  ~LabelExample() override;

  // ExampleBase:
  void CreateExampleView(View* container) override;

  // ButtonListener:
  void ButtonPressed(Button* button, const ui::Event& event) override;

  // ComboboxListener:
  void OnPerformAction(Combobox* combobox) override;

  // TextfieldController:
  void ContentsChanged(Textfield* sender,
                       const base::string16& new_contents) override;

 private:
   // Add a customizable label and various controls to modify its presentation.
   void AddCustomLabel(View* container);

   // Creates and adds a combobox to the layout.
   Combobox* AddCombobox(GridLayout* layout,
                         const char* name,
                         const char** strings,
                         int count);

  Textfield* textfield_;
  Combobox* alignment_;
  Combobox* elide_behavior_;
  std::vector<scoped_ptr<ExampleComboboxModel>> example_combobox_models_;
  Checkbox* multiline_;
  Checkbox* shadows_;
  Label* custom_label_;

  DISALLOW_COPY_AND_ASSIGN(LabelExample);
};

}  // namespace examples
}  // namespace views

#endif  // UI_VIEWS_EXAMPLES_LABEL_EXAMPLE_H_
